% InstrCfg.m
% aegrumet@alum.mit.edu
% November 3, 1999
%
% Define a global variable describing the instrument configuration.
% The InstrumentConfig data structure will carry information
% about the hardware instruments used by the setup:
%
%    - dap board
%    - stimulator
%    - two isolated monitor amplifiers
%
% These should be set according to the instrument configuration and
% their correctness verified before any measurements are taken.
% They should also either be saved with every set of measurements,
% or used to convert the integer-valued data from the DAP board to
% real-valued currents and voltages before saving.

% WARNING: The subfields of this structure need are not set automatically.
% It is up to the user to make sure that the values in InstrumentConfig
% accurately reflect the instrument and/or software configuration.
% If any of these are expected to change during the course of an experiment,
% these variables will also need to be changed at the same time.

clear global InstrumentConfig
global InstrumentConfig

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Dap Board Settings

% The AnalogInFullScaleVolts field is set to the full-scale voltage
% of the analog-to-digital converters on the DAP board.
% The ADC full-scale voltage, which may be one of several
% pre-set values, is set with jumpers on the board itself.
% These routines assume that the ADC has been set for
% biphasic or (positive and negative voltage) operation,
% as opposed to "single-supply" operation.
InstrumentConfig.Dap.AnalogInFullScaleVolts = 5;

% This is the integer representation used by the computer
% for an input voltage of AnalogInFullScaleVolts.
InstrumentConfig.Dap.AnalogInFullScaleInteger = 32768;

% The AnalogOutFullScaleVolts field is set to the full-scale voltage
% of the digital-to-analog converters on the DAP board.
% The DAC full-scale voltage, which may be one of several
% pre-set values, is set with jumpers on the board itself.
% Its value can be checked by running a DAPL script
% which sets the analog output to -32768, measuring
% the voltage with a multi-meter, and taking the
% absolute value [N.B. at the positive end, the board
% only goes up to +32752].  These routines assume that
% the DAC has been set for biphasic or (positive and negative
% voltage) operation, as opposed to "single-supply" operation.
InstrumentConfig.Dap.AnalogOutFullScaleVolts = 10;

% This is the integer representation used by the computer
% for an output voltage of AnalogOutFullScaleVolts.
InstrumentConfig.Dap.AnalogOutFullScaleInteger = 32768;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Stimulator setting

% The MicroampsPerVolt field defines the current source stimulator's
% conversion factor from input voltage to output current.

InstrumentConfig.Stimulator.MicroampsPerVolt = 2;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Monitor Settings
%
% We will assume that there are one or two isolated monitor amplifiers
% for measuring stimulation current or voltage.

% Andrew's current monitor amplifier, Monitor 2, has a conversion factor of
%
%   0.2 V/uA when the divide by 10 jumper is ON
%   2 V/uA when the divide by 10 jumper is OFF
InstrumentConfig.Monitor1.ConversionFactor = .2;
InstrumentConfig.Monitor1.ConversionUnits = 'VoltsPerMicroamp';

InstrumentConfig.Monitor2.ConversionFactor = -.5;
InstrumentConfig.Monitor2.ConversionUnits = 'VoltsPerVolt';

