function RTPltDat

%This function uses a simple algorithm for detecting spikes.
%If more than 10 sample points are found inside the box bounded
%by the four screen cursors, assume a spike has occurred.

global rt;
global ui;
global InstrumentConfig;

% Pull stimulation information out of rt.threshtp instead of global tp.
tp = rt.tp;

if isempty(tp)
  tp = TPDfault;
end

% Define some variables for plotting

t = -1:.01:.01*899;

stim_width = ((rt.tp.pulse1_delay+rt.tp.pulse1_width+ ...
         rt.tp.pulse2_delay+rt.tp.pulse2_width)*rt.tp.update_interval*.001);

width = stim_width+2;
headroom = abs(tp.pulse1_height-tp.pulse2_height)*.2;

% Update various user interface boxes and set axes

if ( ui.RTzoom == 1)
   % Zooming, disable all options if zooming to cursor
   set(findobj(gcf,'Tag','RTxmin'),'Enable','off');
   set(findobj(gcf,'Tag','RTxmax'),'Enable','off');
   set(findobj(gcf,'Tag','RTxminlabel'),'Enable','off');
   set(findobj(gcf,'Tag','RTxmaxlabel'),'Enable','off');
   set(findobj(gcf,'Tag','RTymin'),'Enable','off');
   set(findobj(gcf,'Tag','RTymax'),'Enable','off');
   set(findobj(gcf,'Tag','RTyminlabel'),'Enable','off');
   set(findobj(gcf,'Tag','RTymaxlabel'),'Enable','off');
   set(findobj(gcf,'Tag','RTxrange'),'Enable','off');
   set(findobj(gcf,'Tag','RTxrangelabel'),'Enable','off');

   data_x_headroom = abs(rt.lft-rt.rgt)*.1;
   data_y_headroom = abs(rt.top-rt.bot)*.1;
   dataaxis = [ (min(rt.lft,rt.rgt)-data_x_headroom) ...
                (max(rt.lft,rt.rgt)+data_x_headroom) ...
                (min(rt.top,rt.bot)-data_y_headroom) ...
                (max(rt.top,rt.bot)+data_y_headroom) ];
   monitoraxis = [ (min(rt.lft,rt.rgt)-data_x_headroom) ...
                   (max(rt.lft,rt.rgt)+data_x_headroom) ...
DapOutIntegerToMicroamps(min(tp.pulse1_height,tp.pulse2_height)-headroom) ...
DapOutIntegerToMicroamps(max(tp.pulse1_height,tp.pulse2_height)+headroom)];

else
   % Not zooming, enable appropriate plotting options

   % y-axis
   set(findobj(gcf,'Tag','RTymin'),'Enable','on');
   set(findobj(gcf,'Tag','RTymax'),'Enable','on');
   set(findobj(gcf,'Tag','RTyminlabel'),'Enable','on');
   set(findobj(gcf,'Tag','RTymaxlabel'),'Enable','on');
   Str = sprintf('%.1f',ui.RTymin);
   set(findobj(gcf,'Tag','RTymin'),'String',Str);
   Str = sprintf('%.1f',ui.RTymax);
   set(findobj(gcf,'Tag','RTymax'),'String',Str);

   % x-axis
   set(findobj(gcf,'Tag','RTxrange'),'Enable','on');
   set(findobj(gcf,'Tag','RTxrangelabel'),'Enable','on');
   set(findobj(gcf,'Tag','RTxrange'),'Value',ui.RTxrange);

   if ( ui.RTxrange == 1 )
      % autorange x axis, don't show boxes
      set(findobj(gcf,'Tag','RTxmin'),'Enable','off');
      set(findobj(gcf,'Tag','RTxmax'),'Enable','off');
      set(findobj(gcf,'Tag','RTxminlabel'),'Enable','off');
      set(findobj(gcf,'Tag','RTxmaxlabel'),'Enable','off');
      dataaxis = [0 width ui.RTymin ui.RTymax];
      monitoraxis = [0 width ...
DapOutIntegerToMicroamps(min(tp.pulse1_height,tp.pulse2_height)-headroom) ...
DapOutIntegerToMicroamps(max(tp.pulse1_height,tp.pulse2_height)+headroom)];

   else
      % let user specify x axis range, show boxes with proper values
      set(findobj(gcf,'Tag','RTxmin'),'Enable','on');
      set(findobj(gcf,'Tag','RTxmax'),'Enable','on');
      set(findobj(gcf,'Tag','RTxminlabel'),'Enable','on');
      set(findobj(gcf,'Tag','RTxmaxlabel'),'Enable','on');
  
      Str = sprintf('%.1f',ui.RTxmin);
      set(findobj(gcf,'Tag','RTxmin'),'String',Str);
      Str = sprintf('%.1f',ui.RTxmax);
      set(findobj(gcf,'Tag','RTxmax'),'String',Str);
      dataaxis = [ui.RTxmin ui.RTxmax ui.RTymin ui.RTymax];
      monitoraxis = [ui.RTxmin ui.RTxmax ...
DapOutIntegerToMicroamps(min(tp.pulse1_height,tp.pulse2_height)-headroom) ...
DapOutIntegerToMicroamps(max(tp.pulse1_height,tp.pulse2_height)+headroom)];
   end

end


% Plot to 'Current'; use measurement of threshold current
axes(findobj('Tag','RTCurrent'));
cla;
hold on;

%compute offset from first 50 samples
cm_offset = mean(rt.threshmons(2,1:50));

% samples are taken every 10microseconds, starting 1ms before stimulus onset
cmtime = (0:.01:.01*999) - 1;

plot(cmtime,DapInIntegerToMicroamps(rt.threshmons(2,:) - (ones(1,1000)*cm_offset)));
inc = abs(tp.pulse1_height-tp.pulse2_height)*.2;
axis(monitoraxis);
ylabel('Measured uA');

% Overlay ideal waveform
t2 = 0:.01:(.01*(tp.num_samples-1));

% Just a series of conversion factors.
exact = DapOutIntegerToVolts(TPPlsOut(tp)) * ...
        InstrumentConfig.Stimulator.MicroampsPerVolt;
hold on;
plot(t2,exact,'Color','r','LineStyle','--');
hold off;


% Plot to 'Supra'

axes(findobj('Tag','RTSupra'));
cla;
hold on;
DetectedSpikes = 0;
for h = 1:10
  plot(t,DapInIntegerToVolts(rt.supresp(h,:)));  
  x = find((t > min(rt.lft,rt.rgt)) & (t < max(rt.lft,rt.rgt)));
  y = find ( (DapInIntegerToVolts(rt.supresp(h,x)) > min(rt.top,rt.bot)) & ...
             (DapInIntegerToVolts(rt.supresp(h,x)) < max(rt.top,rt.bot)) );
  if ( size(y,2) > 10 )
     DetectedSpikes = DetectedSpikes + 1;
  end
  if get(findobj('Tag','RTShowSample'),'Value')
    plot(t,DapInIntegerToVolts(rt.sample),'Color',[0 1 0],'LineWidth',2);
  end
end
hold off;
axis(dataaxis);
h1Str = sprintf('%.3f', DapOutIntegerToVolts(rt.suptp.pulse1_height));
h2Str = sprintf('%.3f', DapOutIntegerToVolts(rt.suptp.pulse2_height));
title(['h1=' h1Str ',h2=' h2Str]);
set(findobj('Tag','RTSupRatio'),'String',[num2str(DetectedSpikes) '/10']);

% Plot to 'Threshold'

axes(findobj('Tag','RTThreshold'));
cla;
hold on;
DetectedSpikes = 0;
for h = 1:10
  plot(t,DapInIntegerToVolts(rt.threshresp(h,:)));  
  x = find((t > min(rt.lft,rt.rgt)) & (t < max(rt.lft,rt.rgt)));
  y = find ( (DapInIntegerToVolts(rt.threshresp(h,x)) > min(rt.top,rt.bot)) & ...
             (DapInIntegerToVolts(rt.threshresp(h,x)) < max(rt.top,rt.bot)) );
  if ( size(y,2) > 10 )
     DetectedSpikes = DetectedSpikes + 1;
  end
  if get(findobj('Tag','RTShowSample'),'Value')
    plot(t,DapInIntegerToVolts(rt.sample),'Color',[0 1 0],'LineWidth',2);
  end
end
hold off;
ymin = str2num(get(findobj('Tag','RTymin'),'String'));
ymax = str2num(get(findobj('Tag','RTymax'),'String'));
axis(dataaxis);
h1Str = sprintf('%.3f', DapOutIntegerToVolts(rt.tp.pulse1_height));
h2Str = sprintf('%.3f', DapOutIntegerToVolts(rt.tp.pulse2_height));
title(['h1=' h1Str ',h2=' h2Str]);
set(findobj('Tag','RTThrRatio'),'String',[num2str(DetectedSpikes) '/10']);

% Plot to 'Sub'

axes(findobj('Tag','RTSub'));
cla;
hold on;
DetectedSpikes = 0;
for h = 1:10
  plot(t,DapInIntegerToVolts(rt.subresp(h,:)));  
  x = find((t > min(rt.lft,rt.rgt)) & (t < max(rt.lft,rt.rgt)));
  y = find ( (DapInIntegerToVolts(rt.subresp(h,x)) > min(rt.top,rt.bot)) & ...
             (DapInIntegerToVolts(rt.subresp(h,x)) < max(rt.top,rt.bot)) );
  if ( size(y,2) > 10 )
     DetectedSpikes = DetectedSpikes + 1;
  end
  if get(findobj('Tag','RTShowSample'),'Value')
    plot(t,DapInIntegerToVolts(rt.sample),'Color',[0 1 0],'LineWidth',2);
  end
end
hold off;
ymin = str2num(get(findobj('Tag','RTymin'),'String'));
ymax = str2num(get(findobj('Tag','RTymax'),'String'));
axis(dataaxis);
h1Str = sprintf('%.3f', DapOutIntegerToVolts(rt.subtp.pulse1_height));
h2Str = sprintf('%.3f', DapOutIntegerToVolts(rt.subtp.pulse2_height));
title(['h1=' h1Str ',h2=' h2Str]);
set(findobj('Tag','RTSubRatio'),'String',[num2str(DetectedSpikes) '/10']);

% Remove references to EightChannel amplifier -aeg Nov. 2, 199
% Update RTelectrode text box
%set(findobj('Tag','RTelectrode'),'String', ['Recorded from: ' rt.ename]);

% Update SaveAs button
set(findobj('Tag','RTSaveAs'),'String',UIFileName);

% Draw cursors
RTDrawCurs;

% Enable save buttons
set(findobj('Tag','RTSave'),'Enable','on');
set(findobj('Tag','RTSaveAs'),'Enable','on');

% Compute threshold
thStr = sprintf('%.3f',RTGetTh);
set(findobj('Tag','RTThreshStr'),'String',thStr);

% Update Stimulator Microamps Per Volt
uAperVStr = sprintf('%.2f',InstrumentConfig.Stimulator.MicroampsPerVolt);
set(findobj('Tag','RTMicroampsPerVolt'),'String',uAperVStr);

















