function tp = TPDfault()
%TPDfault: returns twopulse variable tp set to default values

% A structure called tp (which stands for "two pulse") is
% used to store all of the data relevant to the twopulse
% routines.

% The update_interval field is set equal to the number of
% microseconds between subsequent updates of an analog
% output channel.  This parameter should be equal to twice
% the argument of the "time" command in ./dap/twpls.dap.
tp.update_interval = 10;

% The num_samples field is set equal to the number of
% samples sent to each analog output channel for each
% round of stimulation.  This parameter should be equal
% to half of the argument of the "outputwait" command
% in ./dap/twpls.dap.
tp.num_samples = 903;

% The pulse1_delay field contains the number of samples
% which follow the onset of the trigger and precede the
% onset of the first pulse.  The time delay between the
% trigger edge and the onset of the first pulse is
% given by
%      (pulse1_delay + .5)*update_interval
%
tp.pulse1_delay = 3;

% The pulse2_delay field contains the number of samples
% which follow the end of the first pulse and precede the
% onset of the second pulse.  The time delay between
% these events is given by
%      pulse2_delay*update_interval
%
tp.pulse2_delay = 40;

% The pulse1_height and pulse2_height fields contain
% amplitudes of the two pulses.  These parameters must
% be set to integral multiples of 16, and must be between
% -InstrumentConfig.Dap.AnalaogOutFullScaleInteger and
% (InstrumentConfig.Dap.AnalaogOutFullScaleInteger-16).
%
% These parameters correspond to a voltage amplitude of
%      pulse_height*(FullScaleVolts/FullScaleInteger)
%
tp.pulse1_height = 16*41;
tp.pulse2_height = 16*(-41);

% The pulse1_width and pulse2_width fields contain
% the widths of the two pulses.  In microseconds, these
% widths are given by
%      pulse?_width*update_interval
tp.pulse1_width = 40;
tp.pulse2_width = 40;

% The num_stims field holds the number of rounds of
% stimulation to be performed upon pressing the
% start button (within the twopulse environment).
% This field is set to a negative number for an
% unlimited number of rounds of stimulation.
tp.num_stims = 100;

% The frequency field holds the approximate frequency
% of stimulation, in Hz.  Its value should be between
% .1 and 10.
tp.frequency = 10;

% The lockmode field determines if/how the shape of
% the stimulation waveform is preserved when the
% user clicks on one of the delay-, height-, or
% width-changing buttons.
%      lockmode = 1  -> any shape is allowed
%      lockmode = 2  -> lock to a user-defined shape
%      lockmode = 3  -> use one of the default shapes
tp.lockmode = 3;

% The h1h2_ratio, w1w2_ratio, and d2w1_ratio fields
% store the pulse shape when the twopulse routines
% are run in lockmodes 2 and 3.  For charge-balanced
% waveforms, we must have h1h2_ratio = -1/w1w2_ratio,
% but we have intentionally defined these parameters
% independently in case the user wishes to lock to a
% charge-imbalanced waveform.
tp.w1w2_ratio = 1;
tp.h1h2_ratio = -1;
tp.d2w1_ratio = 1;

% The width_tolerance and height_tolerance fields store
% the maximum error allowed in the width and height,
% respectively, when the twopulse routines are run
% in lockmodes 1 and 2.  These parameters are necessary
% because pulse widths and heights can only be set to
% a discrete number of values.  The values assigned
% to these parameters represent the maximum allowed size of
%      abs(longer_width_or_height -
%          (shorter_width_or_height*ratio) )
% where ratio is greater than 1.  For this calculation,
% pulse heights are divided by 16, the smallest allowed
% increment between heights.  Thus, the tolerances express
% the allowed deviations in heights and widths in terms of
% the smallest-grain units.
tp.width_tolerance = .1;
tp.height_tolerance = .1;

% The silent field is a flag which is set to 1 if the
% user would like to run these routines from a script,
% in the absence of a GUI.
tp.silent = 0;

% The np field stores the number of biphasic pulse pairs to be
% sent to the output.  The ipd field stores the inter-pair delay,
% as measured from the end of the first pulse to the beginning of
% the second.  The ipd field is ignored if the np field is set to 1.
tp.np = 1;
tp.ipd = 0;
