function TPNwTxt(tp,action)
%TPNwTxt: update text boxes in twopulse screen.
% Update text in box(es) corresponding to action:
%      Action      Text box
%      ------      -----------------
%        1         pulse1_delay
%        2         pulse2_delay
%        3         pulse1_height
%        4         pulse2_height
%        5         pulse1_width
%        6         pulse2_width
%        7         num_stims
%        8         frequency
%       100        all
%       101        heights only
%       102        widths only

global InstrumentConfig;

OutFullScaleInteger = InstrumentConfig.Dap.AnalogOutFullScaleInteger;
OutFullScaleVolts = InstrumentConfig.Dap.AnalogOutFullScaleVolts;

if tp.silent
  return
end

if ismember(action,[1 100 102])
  Str = sprintf('%4d',(.5+tp.pulse1_delay)*tp.update_interval);
  set(findobj(gcf,'Tag','d1Text'),'String',Str)
end

if ismember(action,[2 100 102])
  Str = sprintf('%4d',tp.pulse2_delay*tp.update_interval);
  set(findobj(gcf,'Tag','d2Text'),'String',Str)
end

% Note that voltages, the h1 and h2 are converted to
% the nearest available voltage from the D/A.

if ismember(action,[3 100 101])
  Str = sprintf('%.3f',(tp.pulse1_height/OutFullScaleInteger)*OutFullScaleVolts);
  set(findobj(gcf,'Tag','h1Text'),'String',Str)
end

if ismember(action,[4 100 101])
  Str = sprintf('%.3f',(tp.pulse2_height/OutFullScaleInteger)*OutFullScaleVolts);
  set(findobj(gcf,'Tag','h2Text'),'String',Str)
end

if ismember(action,[5 100 102])
  Str = sprintf('%4d',tp.pulse1_width*tp.update_interval);
  set(findobj(gcf,'Tag','w1Text'),'String',Str)
end

if ismember(action,[6 100 102])
  Str = sprintf('%4d',tp.pulse2_width*tp.update_interval);
  set(findobj(gcf,'Tag','w2Text'),'String',Str)
end

if ismember(action,[7 100])
  Str = sprintf('%d',tp.num_stims);
  set(findobj(gcf,'Tag','count','Style','text'),'String',Str)
end



