function TPPltPls(tp)
% TPPltPls: Plot twopulse generator waveform.

if tp.silent
  return
end

% If this routine is called by way of a screen other
% than TwoPulse (e.g. ShortRec), don't plot.
if ~isempty(gcbf)
%get(gcbf,'Tag')
  if ~strcmp(get(gcbf,'Tag'),'TwoPulse')
    return
  end
end

pulse1_delay = tp.pulse1_delay;
pulse2_delay = tp.pulse2_delay;
pulse1_height = tp.pulse1_height;
pulse2_height = tp.pulse2_height;
pulse1_width = tp.pulse1_width;
pulse2_width = tp.pulse2_width;

update_interval = tp.update_interval;
num_samples = tp.num_samples;

% Make the 'CommandCurrent' axes active
% Note that we need to use gcbf if this
% function is used as a callback function,
% but must use gcf if not.
if size(gcbf,1) > 0
  handle = gcbf;
else
  handle = gcf;
end

axhandle = findobj(handle,'Tag','CommandCurrent');
axes(axhandle);

% Make a time vector
t = update_interval/2 + ...
   (update_interval * [0:(num_samples-1)]);

% Add a few extra values into the time and voltage
% vectors so that % transitions are drawn vertically,
% since they would be vertical at the output of the D/A
i1 = pulse1_delay+1;
i2 = i1+pulse1_width;
i3 = i2+pulse2_delay;
i4 = i3+pulse2_width;
PulseOut = [zeros(1,size(t(1:i1),2)) ...
            DapOutIntegerToVolts(pulse1_height)* ...
            sign(pulse1_width)*ones(1,size(t(i1:i2),2)) ...
            zeros(1,size(t(i2:i3),2)) ...
            DapOutIntegerToVolts(pulse2_height)* ...
            sign(pulse2_width)*ones(1,size(t(i3:i4),2)) ...
            zeros(1,size(t(i4:num_samples),2))];
t = [t(1:i1) t(i1:i2) t(i2:i3) t(i3:i4) t(i4:num_samples)];

% Plot the waveform
plot([0 t],[0 PulseOut])

% Note that calling the plot routine re-sets all of the
% axes properties.  So we have to rename the tag.
set(axhandle,'Tag','CommandCurrent')

% Resize axes to ignore trailing zeros.
% Assumes a biphasic rectangular pulse waveform.
ax = axis;

axis([0 1.33*t(i4) ax(3) ax(4)])

% Turn on grid
grid on

% Label axes
xlabel('Time (us)')
ylabel('Output (V)')






