function TPSttStp(action)
%TPSttStp: start and stop twopulse stimulation
%
% Note0: This function is one of the few which
% use the twopulse variable tp as a global variable.
% Using tp as a global keeps the loop running quickly
% and greatly eases the programmer's burden.
%
% Note1: This function executes a loop which exists on one of
% several conditions:
%       a) The user clicks on the stop button.
%       b) A finite number of rounds of stimulation is deisred,
%          and that number of stimulations has been applied.
%       c) An infinite number of stimulations is desired, but
%          the tp.silent is 1.  In such a case, there would be
%          no way to stop the stimulator.
%
% Note2: the while loop determines whether or not the stimulator
% is "on" by querying the 'String' property of the start/stop button
% (whose 'Tag' property is 'startstop').
% Pressing the 'start' button sets the 'String' property to 'stop',
% and vice versa.

% Note3: the while loop determines whether or not the # of stimulation
% counts is finite or infinite by querying the 'Value' property of
% the popup menu, whose 'Tag' is 'NumStims'.  A 'Value' of 1 is indicates
% a finite number of stimulations is desired, while a 'Value' of 2
% indicates that an infinite number of stimulations is desired.

global tp

switch action

  case 'start'

    % Open the DAP board and run stimulation routines
    DapRset
    TPDapNit
    TPDapStt

    % Set the number of rounds of stimulation
    NumLeft = tp.num_stims;

    if ~tp.silent
      set(findobj('Tag','startstop'),'BackgroundColor',[1 0 0], ...
      'String','stop','Callback','TPSttStp stop')
      finite = (get(findobj('Tag','NumStims'),'Value') == 1);
    else
      finite = 1;
      if tp.num_stims < 0
        NumLeft = 0;
      end
    end

    while (NumLeft ~= 0) | (~finite)

      % Get Stimulation rate
      hertzval = get(findobj('Tag','hertz'),'Value');

      % Send waveform to DAP
      TPDapSnd(reshape([TPTrgOut(tp)'; TPPlsOut(tp)'],2*tp.num_samples,1));

      % Decrement counter and update screen if a finite # rounds
      if finite
         NumLeft = abs(NumLeft) - 1;
         if ~tp.silent
           Str = sprintf('%d',NumLeft);
      
      % If trying to go as fast as possible, don't update screen
           if hertzval ~= 4
             set(findobj('Tag','count','Style','text'),'String',Str)
           end
         end
      end

      % Pause for an interval, checking for events from GUI
      switch hertzval
         case 1
           period = .5;
         case 2
           period = 1;
         case 3
           period = .2;
      end

      % Don't bother inserting an interval if trying to go as fast as possible
      if hertzval ~= 4
        tic
        while toc < period;
          drawnow
        end
      end

      if ~tp.silent
        % Break out of loop if user pressed stop button.
        if strcmp(get(findobj('Tag','startstop'),'String'),'start')
          break
        end
        % Update finite/infinite property in case user pressed button.
        finite = (get(findobj('Tag','NumStims'),'Value') == 1);
      end

    end
    TPSttStp('stop');

  case 'stop'
    TPDapStp
    if ~tp.silent
      if get(findobj('Tag','NumStims'),'Value') == 1
        Str = sprintf('%d',tp.num_stims);
        set(findobj(gcf,'Tag','count','Style','text'),'String',Str)
      end
      set(findobj('Tag','startstop'),'BackgroundColor',[0 1 0], ...
      'String','start','Callback','TPSttStp start')
    end

end






















