function TriggerOut = TPTrgOut(tp)
%TPTrgOut: Make trigger output waveform for twopulse generator.

global InstrumentConfig;

FullScaleInteger = InstrumentConfig.Dap.AnalogOutFullScaleInteger;
FullScaleVolts = InstrumentConfig.Dap.AnalogOutFullScaleVolts;

%Warn user if full scale is less than 5 volts.
if (FullScaleVolts < 5)
  disp('TPTrgOut:Full scale voltage less than 5 volts.')
  disp('Setting trigger output to full scale.')
  DapAmpl = DapOutMaxInteger;
else
  %Calculate integer output for dap, rounding to the
  %nearest integral multiple of 16.
  DapAmpl =  DapOutVoltsToInteger(5);
end

%Create output vector.  Trigger is HIGH for the duration of the
%stimulation waveform.
%dur = tp.pulse1_delay+tp.pulse2_delay+tp.pulse1_width+tp.pulse2_width;
dur = tp.pulse1_delay+tp.pulse2_delay+tp.pulse1_width+tp.pulse2_width+10;
if (dur < 10)
  dur = 10;
end

% Make trigger waveform longer if multiple pulse pairs selected
if (tp.np > 1)

  TotalWidth = tp.pulse1_delay+tp.pulse1_width+ ...
               tp.pulse2_delay+tp.pulse2_width+tp.ipd;

  MaxNum = floor(tp.num_samples / TotalWidth);

  if (tp.np == 6)
    TotalNum = MaxNum;
  else
    TotalNum = min(tp.np,MaxNum);
  end

  dur = ((dur+tp.ipd-10)*TotalNum)-tp.ipd+10;
  % (reduces to nominal value if TotalNum is one)

end

TriggerOut = DapAmpl * ones(dur,1);
%TriggerOut = DapAmpl * ones(tp.num_samples-1,1);
TriggerOut = [TriggerOut; zeros(tp.num_samples-dur,1)];



