function newtp = TPsw(oldtp,action)
%TPsw: callback functions for twopulse generator

global InstrumentConfig;

newtp = oldtp;

switch action

  % functions for setting pulse1_delay or pulse2_delay
  % or pulse1_width or pulse2_width
  case {'d1g','d1gg','d1l','d1ll' ...
        'd2g','d2gg','d2l','d2ll' ...
        'w1g','w1gg','w1l','w1ll' ...
        'w2g','w2gg','w2l','w2ll'}
    newtp = TPswdw(newtp,action);

  % functions for setting pulse1_height or pulse2_height
  case {'h1g','h1gg','h1ggg','h1l','h1ll','h1lll' ...
        'h2g','h2gg','h2ggg','h2l','h2ll','h2lll'}
    newtp = TPswht(newtp,action);
 
  % functions for setting number of stimulation counts
  case {'numstims','ctg','ctgg','ctl','ctll'}
    newtp = TPswct(newtp,action);

  % function for flipping stimulation waveform about the vertical axis.
  case 'flip'
    newtp.pulse1_height = -1 * newtp.pulse1_height;
    newtp.pulse2_height = -1 * newtp.pulse2_height;
    TPPltPls(newtp);
    TPNwTxt(newtp,101);
 
  % functions for locking and unlocking the stimulus shape
  case 'shapelock'
    newtp = TPswsl(newtp);

  % function for changing MicroampsPerVolt value
  case 'MicroampsPerVolt'
     InstrumentConfig.Stimulator.MicroampsPerVolt = str2num(get(gcbo,'String'));
     
  case 'NumPairs'
    newtp.np = get(gcbo,'Value');
    if (newtp.np == 1)
      set(findobj('Tag','InterPair'),'Visible','off');
      set(findobj('Tag','InterPairLabel'),'Visible','off');
    else
      set(findobj('Tag','InterPair'),'Visible','on');
      set(findobj('Tag','InterPairLabel'),'Visible','on');
      set(findobj('Tag','InterPair','Style','text'), ...
      'String',num2str(newtp.ipd*newtp.update_interval));
    end

  case {'ipdg','ipdl'}
    newtp = TPswipd(newtp,action);

end



