function browse
%browse: Browse data in working directory

DirName = pwd;
DirPrefix = DirName((size(DirName,2)-5):size(DirName,2));

files = dir([DirPrefix '*.mat']);

if isempty(files)
  errordlg('browse error: No .mat files to browse.');
  return
end

clear global br
global br

br.files = [];
for i = 1:size(files,1)
  br.files = [br.files; files(i).name];
end
br.files = sortrows(br.files);

br.index = 1;
br.inview = 255; %A is bit 1, B is bit 2, ..., H is bit 8
br.lockaxes = 255;   %A is bit 1, B is bit 2, ..., H is bit 8

br.fig = figure('Position',[5 30 1016 690],'Tag','browser');

%br.axis = [0 25 -4 1];
%br.usebraxis = 1;

br.axis = [0 50 -4 1];

% Axis values for locked axes
uicontrol('Style','Text','Position',[160 75 50 20], ...
          'String','xmin:');

uicontrol('Style','edit','Position',[220 75 50 20], ...
          'String',num2str(br.axis(1)),'Callback','browsesw xmin');

uicontrol('Style','Text','Position',[160 50 50 20], ...
          'String','xmax:');

uicontrol('Style','edit','Position',[220 50 50 20], ...
          'String',num2str(br.axis(2)),'Callback','browsesw xmax');

uicontrol('Style','Text','Position',[280 75 50 20], ...
          'String','ymin:');

uicontrol('Style','edit','Position',[340 75 50 20], ...
          'String',num2str(br.axis(3)),'Callback','browsesw ymin');

uicontrol('Style','Text','Position',[280 50 50 20], ...
          'String','ymax:');

uicontrol('Style','edit','Position',[340 50 50 20], ...
          'String',num2str(br.axis(4)),'Callback','browsesw ymax');

%back and forward buttons
uicontrol('Style','pushbutton','Position',[50 50 100 50], ...
          'String','back','Callback','browsesw back');

uicontrol('Style','pushbutton','Position',[650 50 100 50], ...
          'String','forward','Callback','browsesw forward');

%Axis locking controls
uicontrol('Style','Text','Position',[770 650 70 20], ...
          'String','Lock Axes','FontSize',12)

for i = 1:8
  uicontrol('Style','checkbox','Position',[780 (630-(24*(i-1))) 45 20], ...
          'String',char(64+i),'FontSize',12','Value',bitget(br.lockaxes,i), ...
          'Callback','browsesw lock','Tag',[char(64+i) 'lock']);
end

uicontrol('Style','Text','Position',[850 650 60 20], ...
          'String','In View','FontSize',12)

%In View controls
for i = 1:8
  uicontrol('Style','checkbox','Position',[860 (630-(24*(i-1))) 45 20], ...
          'String',char(64+i),'FontSize',12','Value',bitget(br.inview,i), ...
          'Callback','browsesw channel','Tag',[char(64+i) 'view']);
end

uicontrol('Style','Text','Position',[920 650 70 20], ...
          'String','Pick One','FontSize',12)

uicontrol('Style','popupmenu','Position',[930 630 45 20], ...
          'String','--|A|B|C|D|E|F|G|H','FontSize',12, ...
          'Callback','browsesw pickone','Tag','pickone');

uicontrol('Style','pushbutton','Position',[920 600 70 25], ...
          'String','All On','FontSize',14, ...
          'Callback','browsesw allon','Tag','allon');

%Select file listbox
uicontrol('Style','listbox','Position',[800 200 200 250], ...
          'String',cellstr(br.files),'Callback','browsesw goto', ...
          'Tag','filelist')

%Display info
uicontrol('Style','Text','Position',[800 150 40 20], ...
          'String','Date:','FontSize',12)

uicontrol('Style','Text','Position',[850 150 140 20], ...
          'Tag','Date','FontSize',12)

uicontrol('Style','Text','Position',[800 120 30 20], ...
          'String','h1:','FontSize',12)

uicontrol('Style','Text','Position',[835 120 50 20], ...
          'Tag','h1','FontSize',12)

uicontrol('Style','Text','Position',[900 120 30 20], ...
          'String','h2:','FontSize',12)

uicontrol('Style','Text','Position',[935 120 50 20], ...
          'Tag','h2','FontSize',12)

brplot








